#[non_exhaustive]pub struct AutonomousDatabaseCharacterSet {
pub name: String,
pub character_set_type: CharacterSetType,
pub character_set: String,
/* private fields */
}Expand description
Details of the Autonomous Database character set resource. https://docs.oracle.com/en-us/iaas/api/#/en/database/20160918/AutonomousDatabaseCharacterSets/
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringIdentifier. The name of the Autonomous Database Character Set resource in the following format: projects/{project}/locations/{region}/autonomousDatabaseCharacterSets/{autonomous_database_character_set}
character_set_type: CharacterSetTypeOutput only. The character set type for the Autonomous Database.
character_set: StringOutput only. The character set name for the Autonomous Database which is the ID in the resource name.
Implementations
Sourceimpl AutonomousDatabaseCharacterSet
impl AutonomousDatabaseCharacterSet
pub fn new() -> Self
Sourcepub fn set_character_set_type<T: Into<CharacterSetType>>(self, v: T) -> Self
pub fn set_character_set_type<T: Into<CharacterSetType>>(self, v: T) -> Self
Sets the value of character_set_type.
Example
ⓘ
use google_cloud_oracledatabase_v1::model::autonomous_database_character_set::CharacterSetType;
let x0 = AutonomousDatabaseCharacterSet::new().set_character_set_type(CharacterSetType::Database);
let x1 = AutonomousDatabaseCharacterSet::new().set_character_set_type(CharacterSetType::National);Sourcepub fn set_character_set<T: Into<String>>(self, v: T) -> Self
pub fn set_character_set<T: Into<String>>(self, v: T) -> Self
Sets the value of character_set.
Example
ⓘ
let x = AutonomousDatabaseCharacterSet::new().set_character_set("example");Trait Implementations
Sourceimpl Clone for AutonomousDatabaseCharacterSet
impl Clone for AutonomousDatabaseCharacterSet
Sourcefn clone(&self) -> AutonomousDatabaseCharacterSet
fn clone(&self) -> AutonomousDatabaseCharacterSet
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for AutonomousDatabaseCharacterSet
impl Default for AutonomousDatabaseCharacterSet
Sourcefn default() -> AutonomousDatabaseCharacterSet
fn default() -> AutonomousDatabaseCharacterSet
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for AutonomousDatabaseCharacterSet
impl PartialEq for AutonomousDatabaseCharacterSet
Sourcefn eq(&self, other: &AutonomousDatabaseCharacterSet) -> bool
fn eq(&self, other: &AutonomousDatabaseCharacterSet) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for AutonomousDatabaseCharacterSet