#[non_exhaustive]pub struct AutonomousDatabaseConnectionStrings {
pub all_connection_strings: Option<AllConnectionStrings>,
pub dedicated: String,
pub high: String,
pub low: String,
pub medium: String,
pub profiles: Vec<DatabaseConnectionStringProfile>,
/* private fields */
}Expand description
The connection string used to connect to the Autonomous Database. https://docs.oracle.com/en-us/iaas/api/#/en/database/20160918/datatypes/AutonomousDatabaseConnectionStrings
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.all_connection_strings: Option<AllConnectionStrings>Output only. Returns all connection strings that can be used to connect to the Autonomous Database.
dedicated: StringOutput only. The database service provides the least level of resources to each SQL statement, but supports the most number of concurrent SQL statements.
high: StringOutput only. The database service provides the highest level of resources to each SQL statement.
low: StringOutput only. The database service provides the least level of resources to each SQL statement.
medium: StringOutput only. The database service provides a lower level of resources to each SQL statement.
profiles: Vec<DatabaseConnectionStringProfile>Output only. A list of connection string profiles to allow clients to group, filter, and select values based on the structured metadata.
Implementations
Sourceimpl AutonomousDatabaseConnectionStrings
impl AutonomousDatabaseConnectionStrings
pub fn new() -> Self
Sourcepub fn set_all_connection_strings<T>(self, v: T) -> Selfwhere
T: Into<AllConnectionStrings>,
pub fn set_all_connection_strings<T>(self, v: T) -> Selfwhere
T: Into<AllConnectionStrings>,
Sets the value of all_connection_strings.
Example
use google_cloud_oracledatabase_v1::model::AllConnectionStrings;
let x = AutonomousDatabaseConnectionStrings::new().set_all_connection_strings(AllConnectionStrings::default()/* use setters */);Sourcepub fn set_or_clear_all_connection_strings<T>(self, v: Option<T>) -> Selfwhere
T: Into<AllConnectionStrings>,
pub fn set_or_clear_all_connection_strings<T>(self, v: Option<T>) -> Selfwhere
T: Into<AllConnectionStrings>,
Sets or clears the value of all_connection_strings.
Example
use google_cloud_oracledatabase_v1::model::AllConnectionStrings;
let x = AutonomousDatabaseConnectionStrings::new().set_or_clear_all_connection_strings(Some(AllConnectionStrings::default()/* use setters */));
let x = AutonomousDatabaseConnectionStrings::new().set_or_clear_all_connection_strings(None::<AllConnectionStrings>);Sourcepub fn set_dedicated<T: Into<String>>(self, v: T) -> Self
pub fn set_dedicated<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_medium<T: Into<String>>(self, v: T) -> Self
pub fn set_medium<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_profiles<T, V>(self, v: T) -> Self
pub fn set_profiles<T, V>(self, v: T) -> Self
Sets the value of profiles.
Example
use google_cloud_oracledatabase_v1::model::DatabaseConnectionStringProfile;
let x = AutonomousDatabaseConnectionStrings::new()
.set_profiles([
DatabaseConnectionStringProfile::default()/* use setters */,
DatabaseConnectionStringProfile::default()/* use (different) setters */,
]);Trait Implementations
Sourceimpl Clone for AutonomousDatabaseConnectionStrings
impl Clone for AutonomousDatabaseConnectionStrings
Sourcefn clone(&self) -> AutonomousDatabaseConnectionStrings
fn clone(&self) -> AutonomousDatabaseConnectionStrings
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Default for AutonomousDatabaseConnectionStrings
impl Default for AutonomousDatabaseConnectionStrings
Sourcefn default() -> AutonomousDatabaseConnectionStrings
fn default() -> AutonomousDatabaseConnectionStrings
Sourceimpl PartialEq for AutonomousDatabaseConnectionStrings
impl PartialEq for AutonomousDatabaseConnectionStrings
Sourcefn eq(&self, other: &AutonomousDatabaseConnectionStrings) -> bool
fn eq(&self, other: &AutonomousDatabaseConnectionStrings) -> bool
self and other values to be equal, and is used by ==.