#[non_exhaustive]pub struct DataCollectionOptions {
pub diagnostics_events_enabled: bool,
pub health_monitoring_enabled: bool,
pub incident_logs_enabled: bool,
/* private fields */
}Expand description
Data collection options for diagnostics.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.diagnostics_events_enabled: boolOptional. Indicates whether diagnostic collection is enabled for the VM cluster
health_monitoring_enabled: boolOptional. Indicates whether health monitoring is enabled for the VM cluster
incident_logs_enabled: boolOptional. Indicates whether incident logs and trace collection are enabled for the VM cluster
Implementations
Sourceimpl DataCollectionOptions
impl DataCollectionOptions
pub fn new() -> Self
Sourcepub fn set_diagnostics_events_enabled<T: Into<bool>>(self, v: T) -> Self
pub fn set_diagnostics_events_enabled<T: Into<bool>>(self, v: T) -> Self
Sets the value of diagnostics_events_enabled.
Example
ⓘ
let x = DataCollectionOptions::new().set_diagnostics_events_enabled(true);Sourcepub fn set_health_monitoring_enabled<T: Into<bool>>(self, v: T) -> Self
pub fn set_health_monitoring_enabled<T: Into<bool>>(self, v: T) -> Self
Sets the value of health_monitoring_enabled.
Example
ⓘ
let x = DataCollectionOptions::new().set_health_monitoring_enabled(true);Sourcepub fn set_incident_logs_enabled<T: Into<bool>>(self, v: T) -> Self
pub fn set_incident_logs_enabled<T: Into<bool>>(self, v: T) -> Self
Sets the value of incident_logs_enabled.
Example
ⓘ
let x = DataCollectionOptions::new().set_incident_logs_enabled(true);Trait Implementations
Sourceimpl Clone for DataCollectionOptions
impl Clone for DataCollectionOptions
Sourcefn clone(&self) -> DataCollectionOptions
fn clone(&self) -> DataCollectionOptions
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DataCollectionOptions
impl Debug for DataCollectionOptions
Sourceimpl Default for DataCollectionOptions
impl Default for DataCollectionOptions
Sourcefn default() -> DataCollectionOptions
fn default() -> DataCollectionOptions
Returns the “default value” for a type. Read more
Sourceimpl Message for DataCollectionOptions
impl Message for DataCollectionOptions
Sourceimpl PartialEq for DataCollectionOptions
impl PartialEq for DataCollectionOptions
impl StructuralPartialEq for DataCollectionOptions