#[non_exhaustive]pub struct DataCollectionOptionsDbSystem {
pub is_diagnostics_events_enabled: bool,
pub is_incident_logs_enabled: bool,
/* private fields */
}Expand description
Data collection options for DbSystem.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.is_diagnostics_events_enabled: boolOptional. Indicates whether to enable data collection for diagnostics.
is_incident_logs_enabled: boolOptional. Indicates whether to enable incident logs and trace collection.
Implementations
Sourceimpl DataCollectionOptionsDbSystem
impl DataCollectionOptionsDbSystem
pub fn new() -> Self
Sourcepub fn set_is_diagnostics_events_enabled<T: Into<bool>>(self, v: T) -> Self
pub fn set_is_diagnostics_events_enabled<T: Into<bool>>(self, v: T) -> Self
Sets the value of is_diagnostics_events_enabled.
Example
ⓘ
let x = DataCollectionOptionsDbSystem::new().set_is_diagnostics_events_enabled(true);Sourcepub fn set_is_incident_logs_enabled<T: Into<bool>>(self, v: T) -> Self
pub fn set_is_incident_logs_enabled<T: Into<bool>>(self, v: T) -> Self
Sets the value of is_incident_logs_enabled.
Example
ⓘ
let x = DataCollectionOptionsDbSystem::new().set_is_incident_logs_enabled(true);Trait Implementations
Sourceimpl Clone for DataCollectionOptionsDbSystem
impl Clone for DataCollectionOptionsDbSystem
Sourcefn clone(&self) -> DataCollectionOptionsDbSystem
fn clone(&self) -> DataCollectionOptionsDbSystem
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for DataCollectionOptionsDbSystem
impl Default for DataCollectionOptionsDbSystem
Sourcefn default() -> DataCollectionOptionsDbSystem
fn default() -> DataCollectionOptionsDbSystem
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for DataCollectionOptionsDbSystem
impl PartialEq for DataCollectionOptionsDbSystem
Sourcefn eq(&self, other: &DataCollectionOptionsDbSystem) -> bool
fn eq(&self, other: &DataCollectionOptionsDbSystem) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for DataCollectionOptionsDbSystem