DatabaseConnectionStringProfile

Struct DatabaseConnectionStringProfile 

#[non_exhaustive]
pub struct DatabaseConnectionStringProfile { pub consumer_group: ConsumerGroup, pub display_name: String, pub host_format: HostFormat, pub is_regional: bool, pub protocol: Protocol, pub session_mode: SessionMode, pub syntax_format: SyntaxFormat, pub tls_authentication: TLSAuthentication, pub value: String, /* private fields */ }
Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
consumer_group: ConsumerGroup

Output only. The current consumer group being used by the connection.

display_name: String

Output only. The display name for the database connection.

host_format: HostFormat

Output only. The host name format being currently used in connection string.

is_regional: bool

Output only. This field indicates if the connection string is regional and is only applicable for cross-region Data Guard.

protocol: Protocol

Output only. The protocol being used by the connection.

session_mode: SessionMode

Output only. The current session mode of the connection.

syntax_format: SyntaxFormat

Output only. The syntax of the connection string.

tls_authentication: TLSAuthentication

Output only. This field indicates the TLS authentication type of the connection.

value: String

Output only. The value of the connection string.

Implementations

Source

impl DatabaseConnectionStringProfile

pub fn new() -> Self

pub fn set_consumer_group<T: Into<ConsumerGroup>>(self, v: T) -> Self

Sets the value of consumer_group.

Example
use google_cloud_oracledatabase_v1::model::database_connection_string_profile::ConsumerGroup;
let x0 = DatabaseConnectionStringProfile::new().set_consumer_group(ConsumerGroup::High);
let x1 = DatabaseConnectionStringProfile::new().set_consumer_group(ConsumerGroup::Medium);
let x2 = DatabaseConnectionStringProfile::new().set_consumer_group(ConsumerGroup::Low);
pub fn set_display_name<T: Into<String>>(self, v: T) -> Self

Sets the value of display_name.

Example
let x = DatabaseConnectionStringProfile::new().set_display_name("example");
pub fn set_host_format<T: Into<HostFormat>>(self, v: T) -> Self

Sets the value of host_format.

Example
use google_cloud_oracledatabase_v1::model::database_connection_string_profile::HostFormat;
let x0 = DatabaseConnectionStringProfile::new().set_host_format(HostFormat::Fqdn);
let x1 = DatabaseConnectionStringProfile::new().set_host_format(HostFormat::Ip);
pub fn set_is_regional<T: Into<bool>>(self, v: T) -> Self

Sets the value of is_regional.

Example
let x = DatabaseConnectionStringProfile::new().set_is_regional(true);
pub fn set_protocol<T: Into<Protocol>>(self, v: T) -> Self

Sets the value of protocol.

Example
use google_cloud_oracledatabase_v1::model::database_connection_string_profile::Protocol;
let x0 = DatabaseConnectionStringProfile::new().set_protocol(Protocol::Tcp);
let x1 = DatabaseConnectionStringProfile::new().set_protocol(Protocol::Tcps);
pub fn set_session_mode<T: Into<SessionMode>>(self, v: T) -> Self

Sets the value of session_mode.

Example
use google_cloud_oracledatabase_v1::model::database_connection_string_profile::SessionMode;
let x0 = DatabaseConnectionStringProfile::new().set_session_mode(SessionMode::Direct);
let x1 = DatabaseConnectionStringProfile::new().set_session_mode(SessionMode::Indirect);
pub fn set_syntax_format<T: Into<SyntaxFormat>>(self, v: T) -> Self

Sets the value of syntax_format.

Example
use google_cloud_oracledatabase_v1::model::database_connection_string_profile::SyntaxFormat;
let x0 = DatabaseConnectionStringProfile::new().set_syntax_format(SyntaxFormat::Long);
let x1 = DatabaseConnectionStringProfile::new().set_syntax_format(SyntaxFormat::Ezconnect);
let x2 = DatabaseConnectionStringProfile::new().set_syntax_format(SyntaxFormat::Ezconnectplus);
pub fn set_tls_authentication<T: Into<TLSAuthentication>>(self, v: T) -> Self

Sets the value of tls_authentication.

Example
use google_cloud_oracledatabase_v1::model::database_connection_string_profile::TLSAuthentication;
let x0 = DatabaseConnectionStringProfile::new().set_tls_authentication(TLSAuthentication::Server);
let x1 = DatabaseConnectionStringProfile::new().set_tls_authentication(TLSAuthentication::Mutual);
pub fn set_value<T: Into<String>>(self, v: T) -> Self

Sets the value of value.

Example
let x = DatabaseConnectionStringProfile::new().set_value("example");