#[non_exhaustive]pub struct DbSystem {
pub name: String,
pub properties: Option<DbSystemProperties>,
pub gcp_oracle_zone: String,
pub labels: HashMap<String, String>,
pub odb_network: String,
pub odb_subnet: String,
pub entitlement_id: String,
pub display_name: String,
pub create_time: Option<Timestamp>,
pub oci_url: String,
/* private fields */
}Expand description
Details of the DbSystem (BaseDB) resource. https://docs.oracle.com/en-us/iaas/api/#/en/database/20160918/DbSystem/
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringIdentifier. The name of the DbSystem resource in the following format: projects/{project}/locations/{region}/dbSystems/{db_system}
properties: Option<DbSystemProperties>Optional. The properties of the DbSystem.
gcp_oracle_zone: StringOptional. The GCP Oracle zone where Oracle DbSystem is hosted. Example: us-east4-b-r2. If not specified, the system will pick a zone based on availability.
labels: HashMap<String, String>Optional. The labels or tags associated with the DbSystem.
odb_network: StringOptional. The name of the OdbNetwork associated with the DbSystem. Format: projects/{project}/locations/{location}/odbNetworks/{odb_network} It is optional but if specified, this should match the parent ODBNetwork of the OdbSubnet.
odb_subnet: StringRequired. The name of the OdbSubnet associated with the DbSystem for IP allocation. Format: projects/{project}/locations/{location}/odbNetworks/{odb_network}/odbSubnets/{odb_subnet}
entitlement_id: StringOutput only. The ID of the subscription entitlement associated with the DbSystem
display_name: StringRequired. The display name for the System db. The name does not have to be unique within your project.
create_time: Option<Timestamp>Output only. The date and time that the DbSystem was created.
oci_url: StringOutput only. HTTPS link to OCI resources exposed to Customer via UI Interface.
Implementations
Sourceimpl DbSystem
impl DbSystem
pub fn new() -> Self
Sourcepub fn set_properties<T>(self, v: T) -> Selfwhere
T: Into<DbSystemProperties>,
pub fn set_properties<T>(self, v: T) -> Selfwhere
T: Into<DbSystemProperties>,
Sets the value of properties.
Example
use google_cloud_oracledatabase_v1::model::DbSystemProperties;
let x = DbSystem::new().set_properties(DbSystemProperties::default()/* use setters */);Sourcepub fn set_or_clear_properties<T>(self, v: Option<T>) -> Selfwhere
T: Into<DbSystemProperties>,
pub fn set_or_clear_properties<T>(self, v: Option<T>) -> Selfwhere
T: Into<DbSystemProperties>,
Sets or clears the value of properties.
Example
use google_cloud_oracledatabase_v1::model::DbSystemProperties;
let x = DbSystem::new().set_or_clear_properties(Some(DbSystemProperties::default()/* use setters */));
let x = DbSystem::new().set_or_clear_properties(None::<DbSystemProperties>);Sourcepub fn set_gcp_oracle_zone<T: Into<String>>(self, v: T) -> Self
pub fn set_gcp_oracle_zone<T: Into<String>>(self, v: T) -> Self
Sets the value of gcp_oracle_zone.
Example
let x = DbSystem::new().set_gcp_oracle_zone("example");Sourcepub fn set_labels<T, K, V>(self, v: T) -> Self
pub fn set_labels<T, K, V>(self, v: T) -> Self
Sourcepub fn set_odb_network<T: Into<String>>(self, v: T) -> Self
pub fn set_odb_network<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_odb_subnet<T: Into<String>>(self, v: T) -> Self
pub fn set_odb_subnet<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_entitlement_id<T: Into<String>>(self, v: T) -> Self
pub fn set_entitlement_id<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_display_name<T: Into<String>>(self, v: T) -> Self
pub fn set_display_name<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_create_time<T>(self, v: T) -> Self
pub fn set_create_time<T>(self, v: T) -> Self
Sets the value of create_time.
Example
use wkt::Timestamp;
let x = DbSystem::new().set_create_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of create_time.
Example
use wkt::Timestamp;
let x = DbSystem::new().set_or_clear_create_time(Some(Timestamp::default()/* use setters */));
let x = DbSystem::new().set_or_clear_create_time(None::<Timestamp>);