#[non_exhaustive]pub struct EncryptionKey {
pub provider: Provider,
pub kms_key: String,
/* private fields */
}Expand description
The encryption key used to encrypt the Autonomous Database.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.provider: ProviderOptional. The provider of the encryption key.
kms_key: StringOptional. The KMS key used to encrypt the Autonomous Database.
This field is required if the provider is GOOGLE_MANAGED.
The name of the KMS key resource in the following format:
projects/{project}/locations/{location}/keyRings/{key_ring}/cryptoKeys/{crypto_key}.
Implementations
Sourceimpl EncryptionKey
impl EncryptionKey