#[non_exhaustive]pub struct EncryptionKeyHistoryEntry {
pub encryption_key: Option<EncryptionKey>,
pub activation_time: Option<Timestamp>,
/* private fields */
}Expand description
The history of the encryption keys used to encrypt the Autonomous Database.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.encryption_key: Option<EncryptionKey>Output only. The encryption key used to encrypt the Autonomous Database.
activation_time: Option<Timestamp>Output only. The date and time when the encryption key was activated on the Autonomous Database..
Implementations
Sourceimpl EncryptionKeyHistoryEntry
impl EncryptionKeyHistoryEntry
pub fn new() -> Self
Sourcepub fn set_encryption_key<T>(self, v: T) -> Selfwhere
T: Into<EncryptionKey>,
pub fn set_encryption_key<T>(self, v: T) -> Selfwhere
T: Into<EncryptionKey>,
Sets the value of encryption_key.
Example
ⓘ
use google_cloud_oracledatabase_v1::model::EncryptionKey;
let x = EncryptionKeyHistoryEntry::new().set_encryption_key(EncryptionKey::default()/* use setters */);Sourcepub fn set_or_clear_encryption_key<T>(self, v: Option<T>) -> Selfwhere
T: Into<EncryptionKey>,
pub fn set_or_clear_encryption_key<T>(self, v: Option<T>) -> Selfwhere
T: Into<EncryptionKey>,
Sets or clears the value of encryption_key.
Example
ⓘ
use google_cloud_oracledatabase_v1::model::EncryptionKey;
let x = EncryptionKeyHistoryEntry::new().set_or_clear_encryption_key(Some(EncryptionKey::default()/* use setters */));
let x = EncryptionKeyHistoryEntry::new().set_or_clear_encryption_key(None::<EncryptionKey>);Sourcepub fn set_activation_time<T>(self, v: T) -> Self
pub fn set_activation_time<T>(self, v: T) -> Self
Sets the value of activation_time.
Example
ⓘ
use wkt::Timestamp;
let x = EncryptionKeyHistoryEntry::new().set_activation_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_activation_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_activation_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of activation_time.
Example
ⓘ
use wkt::Timestamp;
let x = EncryptionKeyHistoryEntry::new().set_or_clear_activation_time(Some(Timestamp::default()/* use setters */));
let x = EncryptionKeyHistoryEntry::new().set_or_clear_activation_time(None::<Timestamp>);Trait Implementations
Sourceimpl Clone for EncryptionKeyHistoryEntry
impl Clone for EncryptionKeyHistoryEntry
Sourcefn clone(&self) -> EncryptionKeyHistoryEntry
fn clone(&self) -> EncryptionKeyHistoryEntry
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for EncryptionKeyHistoryEntry
impl Debug for EncryptionKeyHistoryEntry
Sourceimpl Default for EncryptionKeyHistoryEntry
impl Default for EncryptionKeyHistoryEntry
Sourcefn default() -> EncryptionKeyHistoryEntry
fn default() -> EncryptionKeyHistoryEntry
Returns the “default value” for a type. Read more
Sourceimpl Message for EncryptionKeyHistoryEntry
impl Message for EncryptionKeyHistoryEntry
impl StructuralPartialEq for EncryptionKeyHistoryEntry